summaryrefslogtreecommitdiff
path: root/src/gui
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2007-11-05 15:59:43 +0100
committerSebastien Helleu <flashcode@flashtux.org>2007-11-05 15:59:43 +0100
commit0d66286efe2ca1ee3375cef499a7a629883dc21c (patch)
treee15e3ffb5d73c2cafe548970552bc0ea64bcee20 /src/gui
parenta97e2955be68a91f0e55bbced190e5966bf3391d (diff)
downloadweechat-0d66286efe2ca1ee3375cef499a7a629883dc21c.zip
Added date option for printf functions (weechat core and plugins API)
Diffstat (limited to 'src/gui')
-rw-r--r--src/gui/gui-buffer.h3
-rw-r--r--src/gui/gui-chat.c17
-rw-r--r--src/gui/gui-chat.h5
3 files changed, 17 insertions, 8 deletions
diff --git a/src/gui/gui-buffer.h b/src/gui/gui-buffer.h
index e86a7b194..3b5840272 100644
--- a/src/gui/gui-buffer.h
+++ b/src/gui/gui-buffer.h
@@ -40,7 +40,8 @@ enum t_gui_buffer_type
struct t_gui_line
{
- time_t date; /* date/time of line */
+ time_t date; /* date/time of line (may be past) */
+ time_t date_printed; /* date/time when weechat print it */
char *str_time; /* time string (for display) */
char *prefix; /* prefix for line (may be NULL) */
int prefix_length; /* prefix length (on screen) */
diff --git a/src/gui/gui-chat.h b/src/gui/gui-chat.h
index e2a341924..7addeff1a 100644
--- a/src/gui/gui-chat.h
+++ b/src/gui/gui-chat.h
@@ -22,6 +22,9 @@
#include "gui-buffer.h"
+#define gui_chat_printf(buffer, argz...) \
+ gui_chat_printf_date(buffer, 0, ##argz) \
+
enum t_gui_prefix
{
GUI_CHAT_PREFIX_INFO = 0,
@@ -49,7 +52,7 @@ extern int gui_chat_get_line_align (struct t_gui_buffer *,
struct t_gui_line *, int);
extern int gui_chat_line_search (struct t_gui_line *, char *, int);
extern void gui_chat_line_free (struct t_gui_line *);
-extern void gui_chat_printf (struct t_gui_buffer *, char *, ...);
+extern void gui_chat_printf_date (struct t_gui_buffer *, time_t, char *, ...);
extern void gui_chat_printf_raw_data (void *, int, int, char *);
/* chat functions (GUI dependent) */
diff --git a/src/gui/gui-chat.c b/src/gui/gui-chat.c
index 3e4a1a31b..4ae1c57a9 100644
--- a/src/gui/gui-chat.c
+++ b/src/gui/gui-chat.c
@@ -399,8 +399,8 @@ gui_chat_line_free (struct t_gui_line *line)
*/
void
-gui_chat_line_add (struct t_gui_buffer *buffer, time_t date, char *prefix,
- char *message)
+gui_chat_line_add (struct t_gui_buffer *buffer, time_t date,
+ time_t date_printed, char *prefix, char *message)
{
struct t_gui_line *new_line, *ptr_line;
@@ -413,6 +413,7 @@ gui_chat_line_add (struct t_gui_buffer *buffer, time_t date, char *prefix,
/* add new line */
new_line->date = date;
+ new_line->date_printed = date_printed;
new_line->str_time = (date == 0) ?
NULL : gui_chat_get_time_string (date);
new_line->prefix = (prefix) ?
@@ -446,14 +447,15 @@ gui_chat_line_add (struct t_gui_buffer *buffer, time_t date, char *prefix,
}
/*
* gui_chat_printf: display a message in a buffer
*/
void
-gui_chat_printf (struct t_gui_buffer *buffer, char *message, ...)
+gui_chat_printf_date (struct t_gui_buffer *buffer, time_t date,
+ char *message, ...)
{
static char buf[8192];
- time_t date;
+ time_t date_printed;
int display_time;
char *pos, *pos_prefix, *pos_tab, *pos_end;
va_list argptr;
@@ -476,7 +478,9 @@ gui_chat_printf (struct t_gui_buffer *buffer, char *message, ...)
utf8_normalize (buf, '?');
- date = time (NULL);
+ date_printed = time (NULL);
+ if (date <= 0)
+ date = date_printed;
pos = buf;
while (pos)
@@ -509,6 +513,7 @@ gui_chat_printf (struct t_gui_buffer *buffer, char *message, ...)
if (gui_init_ok)
gui_chat_line_add (buffer, (display_time) ? date : 0,
+ (display_time) ? date_printed : 0,
pos_prefix, pos);
else
{
@@ -446,14 +447,15 @@ gui_chat_line_add (struct t_gui_buffer *buffer, time_t date, char *prefix,
}
/*
- * gui_chat_printf: display a message in a buffer
+ * gui_chat_printf_date: display a message in a buffer
*/
void